UserAIBotBindingViewModel class

Inheritance

Constructors

UserAIBotBindingViewModel()

Properties

bots List<V2NIMUserAIBot>
final
error String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
hasReachedLimit bool
no setter
isLoading bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addBot(V2NIMUserAIBot bot) → void
addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
bind(String qrCode, V2NIMUserAIBot bot) Future<NIMResult<V2NIMUserAIBot>>
dispose() → void
Discards any resources used by the object.
inherited
loadBots() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited