ValidationFriendMessageMerged class

Constructors

ValidationFriendMessageMerged({required NIMFriendAddApplication lastMsg})

Properties

hashCode int
The hash code for this object.
no setterinherited
lastMsg ↔ NIMFriendAddApplication
getter/setter pair
msgList List<NIMFriendAddApplication>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unread bool
getter/setter pair
user ↔ NIMUserInfo?
getter/setter pair

Methods

isSameMessage(NIMFriendAddApplication message) bool
messageUnreadCount() int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pushMessageIfSame(NIMFriendAddApplication message) bool
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited