ValidationMessageViewModel class
- Inheritance
-
- Object
- ChangeNotifier
- ValidationMessageViewModel
Constructors
Properties
-
friendAddApplications
↔ List<
ValidationFriendMessageMerged> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- haveMore ↔ bool
-
getter/setter pair
- lastMessage ↔ NIMFriendAddApplication?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
teamApplications
↔ List<
ValidationTeamMessageMerged> -
getter/setter pair
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
agreeTeamActions(
ValidationTeamMessageMerged mergeMessage, BuildContext context) → void -
agreeUserApplication(
ValidationFriendMessageMerged message, BuildContext context) → void -
cleanTeamActionsMessage(
) → void -
cleanUserApplicationMessage(
) → void -
dispose(
) → void -
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
override
-
init(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
queryNIMFriendAddApplication(
{int offset = 0}) → Future< bool> - 分页请求行通知 如果返回false 表示 需要继续请求
-
queryTeamActions(
) → void -
rejectAddApplication(
ValidationFriendMessageMerged messageMerged, BuildContext context, {String? reason}) → void -
rejectTeamAction(
ValidationTeamMessageMerged messageMerged, BuildContext context, {String? reason}) → void -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- alreadyInTeamCode → const int
- expireLimit → const int
- logTag → const String
- noPermission → const int
- queryMessageLimit → const int
- resInvalid → const int
- teamInvitationNotExist → const int
- teamMemberLimitInvited → const int
- teamMemberNotExist → const int
- teamNotExist → const int