ValidationTeamMessageMerged class
群验证消息
Constructors
- ValidationTeamMessageMerged({required NIMTeamJoinActionInfo lastMsg})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastMsg ↔ NIMTeamJoinActionInfo
-
getter/setter pair
-
msgList
↔ List<
NIMTeamJoinActionInfo> -
getter/setter pair
- readTime ↔ int?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- team ↔ NIMTeam?
-
getter/setter pair
- unread ↔ bool
-
getter/setter pair
- user ↔ NIMUserInfo?
-
getter/setter pair
Methods
-
isSameMessage(
NIMTeamJoinActionInfo message) → bool -
messageUnreadCount(
) → int -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pushMessageIfSame(
NIMTeamJoinActionInfo message) → bool -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited